.. _install:

Installation
============

This documents explains how to install and configure Scrapyd, to deploy and run
your Scrapy spiders.

Requirements
------------

Scrapyd depends on the following libraries, but the installation process
takes care of installing the missing ones:

* Python 3.6 or above
* Scrapy 1.2 or above
* Twisted 17.9 or above

Installing Scrapyd (generic way)
--------------------------------

How to install Scrapyd depends on the platform you're using. The generic way is
to install it from PyPI::

    pip install scrapyd
